@@ -4,7 +4,7 @@
 import pytest
 import tempfile
 
-from calliope import Model
+from calliope import examples
 from calliope.utils import AttrDict
 
 from calliope import analysis
@@ -56,7 +56,7 @@ class TestModel:
 
     @pytest.fixture(scope='module')
     def builtin_model(self):
-        model = Model()
+        model = examples.NationalScale()
         model.run()
         return model
 
@@ -86,30 +86,12 @@ class TestModel:
         lcoe = analysis.get_levelized_cost(model.solution)
         assert_almost_equal(lcoe.at['ccgt'], 0.1)
 
-    def test_get_group_share(self, model):
+    def test_get_group_share(self, model,):
         # TODO this should be tested with a more complex model
-        share = analysis.get_group_share(model.solution, techs=['ccgt'])
+        share = analysis.get_group_share(model.solution, techs=['ccgt'], group='supply')
         assert share == 1.0
 
     def test_get_unmet_demand_hours(self, builtin_model):
         # TODO this should be tested with a more complex model
         unmet = analysis.get_unmet_demand_hours(builtin_model.solution)
         assert unmet == 1
-
-    def test_recompute_levelized_costs(self, model):
-        # Cost in solution
-        sol = model.solution
-        assert_almost_equal(sol['summary'].to_pandas().loc['ccgt', 'levelized_cost_monetary'], 0.1)
-        # Recomputed cost must be the same
-        dm = analysis.SolutionModel(model.solution)
-        recomputed = dm.recompute_levelized_costs('ccgt')
-        assert_almost_equal(recomputed['total'], 0.1)
-
-    def test_recompute_levelized_costs_after_changes(self, model):
-        # Make changes
-        dm = analysis.SolutionModel(model.solution)
-        dm.config_model.techs.ccgt.costs.monetary.e_cap = 50
-        dm.config_model.techs.ccgt.costs.monetary.om_fuel = 1.0
-        # Recomputed cost
-        recomputed = dm.recompute_levelized_costs('ccgt')
-        assert_almost_equal(recomputed['total'], 1.0, tolerance=0.001)
